@@ -8,6 +8,7 @@ import numpy as np
 # from d3m_metadata import hyperparams, params
 from d3m_metadata import container, hyperparams, metadata as metadata_module, params, utils
 from primitive_interfaces.supervised_learning import SupervisedLearnerPrimitiveBase
+from primitive_interfaces.base import CallResult
 # from . import __version__
 
 
@@ -62,7 +63,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.8',
+        'version': '2.0.9',
         'name': 'IPCMB feature selector',
         'keywords': 'rpi primitives',
         'source': {
@@ -119,12 +120,12 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
         os.remove('rpi_data.mat')
 
-        return True
+        return CallResult(None)
 
 
     def produce(self, inputs: Inputs) -> Outputs:  # inputs: m x n numpy array
         if self.fitted:
-            return inputs[:, self.index]
+            return CallResult(inputs[:, self.index])
         else:
             raise ValueError('Model should be fitted first.')
 
